@@ -406,7 +406,6 @@ from sklearn.naive_bayes import GaussianNB
 from sklearn import cluster
 import numpy as np
 
-from lazyearth.mainfile import objearth as oe
 
 class water:
         #fix
@@ -444,10 +443,17 @@ class water:
         clustering_method = 'agglomerative'
         
         def __init__(self,bands):
-            self.bands = bands
+            self.bands = bands   
+            
+        def __str__(self):
+            lst = list()
+            for i in self.bands.keys():
+                lst.append(i)
+            lst = str(lst)
+            return "bands : "+lst 
     
         def show(self):
-            oe.plotshow(oe.band_combination(self.bands['Red'],self.bands['Green'],self.bands['Blue'],5))
+            # oe.plotshow(oe.band_combination(self.bands['Red'],self.bands['Green'],self.bands['Blue'],5))
             print(self.bands)
             
         ############################################ DWImageClustering ############################################
@@ -846,4 +852,4 @@ class water:
             water_mask = np.where(cluster_matrix == 1,1,np.where(invalid_mask == 1,255,0)).astype('int8')
             watermask0 = water_mask==0
             watermask1 = water_mask==1
-            return watermask1,water_mask
\ No newline at end of file
+            return watermask1
\ No newline at end of file
